import { Component, EventEmitter, Inject, Injectable, Input, NgModule, Optional, Output, Pipe, SkipSelf } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MAT_DIALOG_DATA, MatButtonModule, MatCheckboxModule, MatDialog, MatDialogModule, MatDialogRef, MatInputModule, MatProgressBarModule, MatProgressSpinnerModule, MatSelectModule, MatTooltipModule } from '@angular/material';
import { HttpClient } from '@angular/common/http';
import { JwtHelper } from 'angular2-jwt';
import { Observable as Observable$1 } from 'rxjs/Observable';
import 'rxjs/add/observable/of';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/** @enum {number} */
var ConfirmationDialogMode = {
    OkCancel: 0,
    YesNo: 1,
    TrueFalse: 2,
};
ConfirmationDialogMode[ConfirmationDialogMode.OkCancel] = "OkCancel";
ConfirmationDialogMode[ConfirmationDialogMode.YesNo] = "YesNo";
ConfirmationDialogMode[ConfirmationDialogMode.TrueFalse] = "TrueFalse";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var DialogComponent = (function () {
    function DialogComponent() {
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
        this.mode = ConfirmationDialogMode.OkCancel;
    }
    /**
     * @return {?}
     */
    DialogComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        if (this.data) {
            this.title = this.data.title || null;
            this.message = this.data.message || null;
            this.checkboxMessage = this.data.checkboxMessage || null;
            this.placeholder = this.data.placeholder || null;
            this.mode = this.data.mode || ConfirmationDialogMode.OkCancel;
        }
    };
    /**
     * @return {?}
     */
    DialogComponent.prototype.close = /**
     * @return {?}
     */
    function () {
        var /** @type {?} */ data;
        switch (this.dialogType) {
            case 'message':
                data = this.checkboxMessage ?
                    {
                        checkbox: this.checkboxValue
                    } :
                    null;
                break;
            case 'input':
                data = this.checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue
                    } :
                    this.userInput;
                break;
            case 'confirmation':
                data = this.checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    };
    /**
     * @return {?}
     */
    DialogComponent.prototype.cancel = /**
     * @return {?}
     */
    function () {
        var /** @type {?} */ data;
        if (this.dialogType === 'confirmation') {
            data = this.checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue
                } :
                false;
        }
        this.closed.emit(data);
    };
    DialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'cp-dialog',
                    template: "<h2 *ngIf=\"title\" mat-dialog-title [innerHTML]=\"title\"></h2> <mat-dialog-content> <div *ngIf=\"message\" [innerHTML]=\"message\"></div> <mat-form-field *ngIf=\"dialogType === 'input'\"> <textarea matInput [placeholder]=\"placeholder\" [(ngModel)]=\"userInput\"></textarea> </mat-form-field> <mat-checkbox *ngIf=\"checkboxMessage\" [(ngModel)]=\"checkboxValue\"><span [innerHTML]=\"checkboxMessage\"></span></mat-checkbox> </mat-dialog-content> <mat-dialog-actions> <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType === 'input' && !userInput\"> <span [ngSwitch]=\"mode\"> <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">Yes</span> <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">True</span> <span *ngSwitchDefault>OK</span> </span> </button> <button *ngIf=\"dialogType !== 'message'\" mat-raised-button (click)=\"cancel()\"> <span [ngSwitch]=\"mode\"> <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">No</span> <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">False</span> <span *ngSwitchDefault>Cancel</span> </span> </button> </mat-dialog-actions>",
                    styles: ["mat-form-field { margin-top: 2em; width: 100%; } mat-checkbox { margin: 2em; }"]
                },] },
    ];
    /** @nocollapse */
    DialogComponent.ctorParameters = function () { return []; };
    DialogComponent.propDecorators = {
        "dialogType": [{ type: Input },],
        "data": [{ type: Input },],
        "closed": [{ type: Output },],
    };
    return DialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ConfirmationDialogComponent = (function () {
    function ConfirmationDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    ConfirmationDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'cp-confirmation-dialog',
                    template: "<cp-dialog [data]=\"data\" [dialogType]=\"'confirmation'\" (closed)=\"dialogRef.close($event)\"> </cp-dialog>"
                },] },
    ];
    /** @nocollapse */
    ConfirmationDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef, },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] },] },
    ]; };
    return ConfirmationDialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var InputDialogComponent = (function () {
    function InputDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    InputDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'cp-input-dialog',
                    template: "<cp-dialog [data]=\"data\" [dialogType]=\"'input'\" (closed)=\"dialogRef.close($event)\"> </cp-dialog>"
                },] },
    ];
    /** @nocollapse */
    InputDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef, },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] },] },
    ]; };
    return InputDialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var MessageDialogComponent = (function () {
    function MessageDialogComponent(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    MessageDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'cp-message-dialog',
                    template: "<cp-dialog [data]=\"data\" [dialogType]=\"'message'\" (closed)=\"dialogRef.close()\"> </cp-dialog>"
                },] },
    ];
    /** @nocollapse */
    MessageDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef, },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] },] },
    ]; };
    return MessageDialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
// Components
var DialogModule = (function () {
    function DialogModule() {
    }
    DialogModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatInputModule,
                        MatDialogModule
                    ],
                    declarations: [
                        DialogComponent,
                        ConfirmationDialogComponent,
                        InputDialogComponent,
                        MessageDialogComponent
                    ],
                    exports: [
                        ConfirmationDialogComponent,
                        InputDialogComponent,
                        MessageDialogComponent
                    ],
                    entryComponents: [
                        ConfirmationDialogComponent,
                        InputDialogComponent,
                        MessageDialogComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    DialogModule.ctorParameters = function () { return []; };
    return DialogModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var AuthenticationServiceConfig = (function () {
    function AuthenticationServiceConfig() {
    }
    return AuthenticationServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SharePointServiceConfig = (function () {
    function SharePointServiceConfig() {
    }
    return SharePointServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var SharePointService = (function () {
    //#endregion
    function SharePointService(config, http$$1) {
        this.http = http$$1;
        this.sharePointApiUrl = config.sharePointApiUrl;
    }
    //#region Utilities
    /**
     * @param {?} list
     * @return {?}
     */
    SharePointService.prototype.getListItems = /**
     * @param {?} list
     * @return {?}
     */
    function (list) {
        return this.http.post(this.sharePointApiUrl, list);
    };
    /**
     * @param {?} list
     * @param {?} view
     * @param {?=} site
     * @param {?=} limit
     * @return {?}
     */
    SharePointService.prototype.getListItemsSimple = /**
     * @param {?} list
     * @param {?} view
     * @param {?=} site
     * @param {?=} limit
     * @return {?}
     */
    function (list, view, site, limit) {
        return this.http.get(this.sharePointApiUrl + "/" + list + "/" + view + "/" + site + "/" + limit);
    };
    /**
     * @param {?=} storePeople
     * @return {?}
     */
    SharePointService.prototype.getPeople = /**
     * @param {?=} storePeople
     * @return {?}
     */
    function (storePeople) {
        var _this = this;
        // Do we already have people stored locally?
        if (this.people) {
            return Observable$1.of(this.people);
        }
        // Should we store people locally for subsequent calls?
        if (storePeople) {
            this.http.get(this.sharePointApiUrl + "/people")
                .subscribe(function (peeps) { return _this.people = peeps; });
        }
        return this.http.get(this.sharePointApiUrl + "/people");
    };
    /**
     * @param {?=} storePhotos
     * @return {?}
     */
    SharePointService.prototype.getPhotos = /**
     * @param {?=} storePhotos
     * @return {?}
     */
    function (storePhotos) {
        var _this = this;
        // Do we already have photos stored locally?
        if (this.photos) {
            return Observable$1.of(this.photos);
        }
        var /** @type {?} */ spList = {
            list: 'Employee Thumbnail Photos',
            view: 'All Pictures',
            site: 'http://cpsp1/DigitalDisplay'
        };
        // Should we store photos locally for subsequent calls?
        if (storePhotos) {
            this.http.post(this.sharePointApiUrl, spList)
                .subscribe(function (photos) { return _this.photos = photos; });
        }
        return this.http.post(this.sharePointApiUrl, spList);
    };
    /**
     * @return {?}
     */
    SharePointService.prototype.getCustomerVisits = /**
     * @return {?}
     */
    function () {
        var /** @type {?} */ list = {
            list: 'Customer Visits',
            view: 'All Events'
        };
        return this.http.post(this.sharePointApiUrl, list);
    };
    //#endregion
    SharePointService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    SharePointService.ctorParameters = function () { return [
        { type: SharePointServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    return SharePointService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var AuthenticationService = (function () {
    //#endregion
    //#region Lifecycle
    function AuthenticationService(config, http$$1, sharePointService) {
        this.http = http$$1;
        this.sharePointService = sharePointService;
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        this.authenticating = false;
        this.authenticated = false;
        this.authenticationApiUrl = config.authenticationApiUrl;
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    /**
     * @param {?} username
     * @param {?} password
     * @param {?=} adminGroup
     * @return {?}
     */
    AuthenticationService.prototype.login = /**
     * @param {?} username
     * @param {?} password
     * @param {?=} adminGroup
     * @return {?}
     */
    function (username, password, adminGroup) {
        var _this = this;
        var /** @type {?} */ today = new Date();
        var /** @type {?} */ expiration = new Date().setFullYear(today.getFullYear() + 10);
        var /** @type {?} */ request = {
            username: username,
            password: password,
            adminGroup: adminGroup,
            expirationDate: expiration // moment().add(10, 'years').toDate()
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        this.http.post(this.authenticationApiUrl, request)
            .subscribe(function (token) { return _this.validateUser(token); }, function (err) {
            _this.authenticating = false;
            _this.authenticatingChanged.emit(_this.authenticating);
        });
    };
    /**
     * @return {?}
     */
    AuthenticationService.prototype.logout = /**
     * @return {?}
     */
    function () {
        if (localStorage.getItem('token')) {
            localStorage.removeItem('token');
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    };
    /**
     * @param {?} token
     * @return {?}
     */
    AuthenticationService.prototype.validateUser = /**
     * @param {?} token
     * @return {?}
     */
    function (token) {
        if (!token) {
            return;
        }
        var /** @type {?} */ jwtHelper = new JwtHelper();
        var /** @type {?} */ decoded = /** @type {?} */ (jwtHelper.decodeToken(token));
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber
        };
        localStorage.setItem('token', token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    };
    /**
     * @return {?}
     */
    AuthenticationService.prototype.getPhoto = /**
     * @return {?}
     */
    function () {
        var _this = this;
        if (!this.authenticatedUser || !this.authenticatedUser.employeeNumber) {
            return;
        }
        this.sharePointService.getPhotos()
            .subscribe(function (photos) {
            var /** @type {?} */ photo = photos.find(function (pic) { return +pic.ows_EmployeeNumber === +_this.authenticatedUser.employeeNumber; });
            if (photo) {
                _this.authenticatedUser.photoUrl = photo.ows_EncodedAbsUrl;
            }
        });
    };
    /**
     * @return {?}
     */
    AuthenticationService.prototype.checkForExistingToken = /**
     * @return {?}
     */
    function () {
        if (localStorage.getItem('token')) {
            this.validateUser(localStorage.getItem('token'));
        }
    };
    //#endregion
    AuthenticationService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AuthenticationService.ctorParameters = function () { return [
        { type: AuthenticationServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
        { type: SharePointService, },
    ]; };
    AuthenticationService.propDecorators = {
        "authenticatedChanged": [{ type: Output },],
        "authenticatingChanged": [{ type: Output },],
    };
    return AuthenticationService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var LoginFormComponent = (function () {
    function LoginFormComponent(dialogRef, sharePointService, authenticationService) {
        this.dialogRef = dialogRef;
        this.sharePointService = sharePointService;
        this.authenticationService = authenticationService;
    }
    /**
     * @return {?}
     */
    LoginFormComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.authenticationService.authenticatedChanged
            .subscribe(function (authenticated) {
            if (authenticated) {
                _this.dialogRef.close();
            }
        });
    };
    /**
     * @return {?}
     */
    LoginFormComponent.prototype.authenticate = /**
     * @return {?}
     */
    function () {
        if (!this.sharePointService || !this.username || !this.password) {
            return;
        }
        this.authenticationService.login(this.username, this.password);
    };
    LoginFormComponent.decorators = [
        { type: Component, args: [{
                    selector: 'cp-login-form',
                    template: "<h2 mat-dialog-title> <span *ngIf=\"!authenticationService.authenticating\">Login</span> <span *ngIf=\"authenticationService.authenticating\">Authenticating...</span> </h2> <mat-dialog-content [class.loginError]=\"loginError\"> <div id=\"spinner\" *ngIf=\"authenticationService.authenticating\"> <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"></mat-progress-spinner> </div> <div *ngIf=\"!authenticationService.authenticating\"> <div> <mat-form-field> <input matInput placeholder=\"Username\" [(ngModel)]=\"username\" name=\"username\" required (keyup.enter)=\"authenticate()\"> </mat-form-field> </div> <div> <mat-form-field> <input matInput type=\"password\" placeholder=\"Password\" [(ngModel)]=\"password\" name=\"password\" required (keyup.enter)=\"authenticate()\"> </mat-form-field> </div> </div> <div *ngIf=\"!authenticationService.authenticating && loginError\" class=\"alert alert-danger\"> Bad username or password </div> </mat-dialog-content> <mat-dialog-actions *ngIf=\"!authenticationService.authenticating\"> <button type=\"button\" mat-raised-button (click)=\"authenticate()\">OK</button> <button type=\"button\" mat-button (click)=\"dialogRef.close()\">Cancel</button> </mat-dialog-actions>",
                    styles: ["#spinner { width: 100%; height: 100%; display: flex; justify-content: center; align-items: center; } mat-dialog-content { height: 150px; } mat-dialog-content.loginError { height: 200px; }"]
                },] },
    ];
    /** @nocollapse */
    LoginFormComponent.ctorParameters = function () { return [
        { type: MatDialogRef, },
        { type: SharePointService, },
        { type: AuthenticationService, },
    ]; };
    return LoginFormComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var LoginComponent = (function () {
    function LoginComponent(dialog, authenticationService) {
        this.dialog = dialog;
        this.authenticationService = authenticationService;
    }
    /**
     * @return {?}
     */
    LoginComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    /**
     * @return {?}
     */
    LoginComponent.prototype.login = /**
     * @return {?}
     */
    function () {
        this.dialog.open(LoginFormComponent);
    };
    /**
     * @return {?}
     */
    LoginComponent.prototype.confirmLogout = /**
     * @return {?}
     */
    function () {
        var _this = this;
        var /** @type {?} */ dialogRef = this.dialog.open(ConfirmationDialogComponent, {
            data: { message: "Are you sure you want to logout?" }
        });
        dialogRef.afterClosed().subscribe(function (result) {
            if (result) {
                _this.authenticationService.logout();
            }
        });
    };
    LoginComponent.decorators = [
        { type: Component, args: [{
                    selector: 'cp-login',
                    template: "<div id=\"user-id\"> <i id=\"unauthenticated-user-image\" *ngIf=\"!authenticationService.authenticated\" class=\"fa fa-user-circle\" [class.fa-spin]=\"authenticationService.authenticating\" aria-hidden=\"true\" title=\"Login\" (click)=\"login()\"></i> <img id=\"authenticated-user-image\" *ngIf=\"authenticationService.authenticated && authenticationService.authenticatedUser.photoUrl\" [src]=\"authenticationService.authenticatedUser.photoUrl\" title=\"Logout\" (click)=\"confirmLogout()\" /> <div id=\"user-name\" *ngIf=\"authenticationService.authenticated\"> {{ authenticationService.authenticatedUser.displayName }} </div> </div>",
                    styles: ["#user-id { display: flex; height: 2em; padding: .3em; font-family: Verdana, Geneva, Tahoma, sans-serif; } .fa { font-size: 2em; } img { border-radius: 100%; width: 2em; height: 2em; } #user-id > div { display: flex; align-items: center; height: 100%; margin-left: .75em; font-size: 1.15em; }"]
                },] },
    ];
    /** @nocollapse */
    LoginComponent.ctorParameters = function () { return [
        { type: MatDialog, },
        { type: AuthenticationService, },
    ]; };
    return LoginComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
// Modules
// Services
// Components
var AuthenticationModule = (function () {
    function AuthenticationModule(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} authenticationConfig
     * @return {?}
     */
    AuthenticationModule.forRoot = /**
     * @param {?} authenticationConfig
     * @return {?}
     */
    function (authenticationConfig) {
        return {
            ngModule: AuthenticationModule,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    };
    AuthenticationModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatDialogModule,
                        MatInputModule,
                        MatProgressBarModule,
                        MatProgressSpinnerModule,
                        MatTooltipModule,
                        MatSelectModule,
                        DialogModule
                    ],
                    declarations: [
                        LoginComponent,
                        LoginFormComponent
                    ],
                    exports: [
                        LoginComponent,
                        LoginFormComponent
                    ],
                    providers: [],
                    entryComponents: [
                        LoginFormComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    AuthenticationModule.ctorParameters = function () { return [
        { type: AuthenticationModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return AuthenticationModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmailServiceConfig = (function () {
    function EmailServiceConfig() {
    }
    return EmailServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var EmailService = (function () {
    function EmailService(config, http$$1) {
        this.http = http$$1;
        this.emailServiceConfig = config;
    }
    /**
     * @param {?} email
     * @return {?}
     */
    EmailService.prototype.send = /**
     * @param {?} email
     * @return {?}
     */
    function (email) {
        var /** @type {?} */ dto = {
            server: this.emailServiceConfig.server,
            smtpPort: this.emailServiceConfig.smtpPort,
            sender: this.emailServiceConfig.sender,
            subject: email.subject,
            content: email.content,
            recipients: email.recipients
        };
        return this.http.post(this.emailServiceConfig.emailApiUrl, dto);
    };
    EmailService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    EmailService.ctorParameters = function () { return [
        { type: EmailServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    return EmailService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
// Services
var EmailModule = (function () {
    function EmailModule(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} emailConfig
     * @return {?}
     */
    EmailModule.forRoot = /**
     * @param {?} emailConfig
     * @return {?}
     */
    function (emailConfig) {
        return {
            ngModule: EmailModule,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    };
    EmailModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [],
                    exports: []
                },] },
    ];
    /** @nocollapse */
    EmailModule.ctorParameters = function () { return [
        { type: EmailModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return EmailModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmployeeServiceConfig = (function () {
    function EmployeeServiceConfig() {
    }
    return EmployeeServiceConfig;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
var EmployeeService = (function () {
    //#endregion
    //#region Lifecycle
    function EmployeeService(config, http$$1) {
        this.http = http$$1;
        this.employeeApiUrl = config.employeeApiUrl;
    }
    //#endregion
    //#region Utilities
    /**
     * @param {?=} storeEmployees
     * @return {?}
     */
    EmployeeService.prototype.getEmployees = /**
     * @param {?=} storeEmployees
     * @return {?}
     */
    function (storeEmployees) {
        var _this = this;
        // Do we already have employees stored locally?
        if (this.employees) {
            return Observable$1.of(this.employees);
        }
        // Should we store employees locally for subsequent calls?
        if (storeEmployees) {
            this.http.get(this.employeeApiUrl)
                .subscribe(function (emps) { return _this.employees = emps; });
        }
        return this.http.get(this.employeeApiUrl);
    };
    /**
     * @param {?} sAMAccountName
     * @return {?}
     */
    EmployeeService.prototype.getEmployee = /**
     * @param {?} sAMAccountName
     * @return {?}
     */
    function (sAMAccountName) {
        return this.http.get(this.employeeApiUrl + "/name/" + sAMAccountName);
    };
    //#endregion
    EmployeeService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    EmployeeService.ctorParameters = function () { return [
        { type: EmployeeServiceConfig, decorators: [{ type: Optional },] },
        { type: HttpClient, },
    ]; };
    return EmployeeService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var DepartmentsPipe = (function () {
    function DepartmentsPipe() {
    }
    /**
     * @param {?} employees
     * @param {?=} args
     * @return {?}
     */
    DepartmentsPipe.prototype.transform = /**
     * @param {?} employees
     * @param {?=} args
     * @return {?}
     */
    function (employees, args) {
        var /** @type {?} */ departments = [];
        employees
            .filter(function (emp) { return emp.department; })
            .forEach(function (emp) {
            if (departments.indexOf(emp.department) === -1) {
                departments.push(emp.department);
            }
        });
        return departments.sort();
    };
    DepartmentsPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'departments'
                },] },
    ];
    /** @nocollapse */
    DepartmentsPipe.ctorParameters = function () { return []; };
    return DepartmentsPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmployeeByDnPipe = (function () {
    function EmployeeByDnPipe() {
    }
    /**
     * @param {?} employees
     * @param {?} dn
     * @return {?}
     */
    EmployeeByDnPipe.prototype.transform = /**
     * @param {?} employees
     * @param {?} dn
     * @return {?}
     */
    function (employees, dn) {
        return employees
            .find(function (emp) { return emp.distinguishedName.toLowerCase() === dn.toLowerCase(); });
    };
    EmployeeByDnPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'employeeByDn'
                },] },
    ];
    /** @nocollapse */
    EmployeeByDnPipe.ctorParameters = function () { return []; };
    return EmployeeByDnPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmployeePhotoUrlPipe = (function () {
    function EmployeePhotoUrlPipe() {
    }
    /**
     * @param {?} employee
     * @param {?} photos
     * @return {?}
     */
    EmployeePhotoUrlPipe.prototype.transform = /**
     * @param {?} employee
     * @param {?} photos
     * @return {?}
     */
    function (employee, photos) {
        if (!photos) {
            return null;
        }
        var /** @type {?} */ photo;
        // Try to match by employeeNumber, accountName, or title
        photos
            .filter(function (pic) {
            return (pic.ows_EmployeeNumber && employee.employeeNumber && +pic.ows_EmployeeNumber === +employee.employeeNumber) ||
                (pic.ows_AccountName && pic.ows_AccountName.toLowerCase() === employee.sAMAccountName.toLowerCase()) ||
                (pic.ows_Title && pic.ows_Title.toLowerCase() === employee.displayName.toLowerCase());
        })
            .forEach(function (pic) { return photo = pic; });
        if (!photo) {
            console.log("No photo match for " + employee.displayName);
        }
        return photo ? photo.ows_EncodedAbsUrl : null;
    };
    EmployeePhotoUrlPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'employeePhotoUrl'
                },] },
    ];
    /** @nocollapse */
    EmployeePhotoUrlPipe.ctorParameters = function () { return []; };
    return EmployeePhotoUrlPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EmployeesWithPropertyValuePipe = (function () {
    function EmployeesWithPropertyValuePipe() {
    }
    /**
     * @param {?} employees
     * @param {?} propertyName
     * @param {?} propertyValue
     * @return {?}
     */
    EmployeesWithPropertyValuePipe.prototype.transform = /**
     * @param {?} employees
     * @param {?} propertyName
     * @param {?} propertyValue
     * @return {?}
     */
    function (employees, propertyName, propertyValue) {
        return employees
            .filter(function (emp) { return emp[propertyName] && emp[propertyName] === propertyValue; });
    };
    EmployeesWithPropertyValuePipe.decorators = [
        { type: Pipe, args: [{
                    name: 'employeesWithPropertyValue'
                },] },
    ];
    /** @nocollapse */
    EmployeesWithPropertyValuePipe.ctorParameters = function () { return []; };
    return EmployeesWithPropertyValuePipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var FilterEmployeesPipe = (function () {
    function FilterEmployeesPipe() {
    }
    /**
     * @param {?} employees
     * @param {?} filter
     * @return {?}
     */
    FilterEmployeesPipe.prototype.transform = /**
     * @param {?} employees
     * @param {?} filter
     * @return {?}
     */
    function (employees, filter) {
        return filter ?
            employees
                .filter(function (emp) {
                return emp.displayName.toLowerCase().indexOf(filter.toLowerCase()) !== -1 ||
                    (emp.department && emp.department.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                    (emp.title && emp.title.toLowerCase().indexOf(filter.toLowerCase()) !== -1) ||
                    emp.sAMAccountName.toLowerCase().indexOf(filter.toLowerCase()) !== -1;
            }) :
            employees;
    };
    FilterEmployeesPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'filterEmployees'
                },] },
    ];
    /** @nocollapse */
    FilterEmployeesPipe.ctorParameters = function () { return []; };
    return FilterEmployeesPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var IsMemberOfPipe = (function () {
    function IsMemberOfPipe() {
    }
    /**
     * @param {?} employee
     * @param {?} groupName
     * @return {?}
     */
    IsMemberOfPipe.prototype.transform = /**
     * @param {?} employee
     * @param {?} groupName
     * @return {?}
     */
    function (employee, groupName) {
        return employee.memberOf &&
            (employee.memberOf.find(function (m) { return m.toLowerCase().indexOf(groupName.toLowerCase()) !== -1; }) !== undefined);
    };
    IsMemberOfPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'isMemberOf'
                },] },
    ];
    /** @nocollapse */
    IsMemberOfPipe.ctorParameters = function () { return []; };
    return IsMemberOfPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SortEmployeesPipe = (function () {
    function SortEmployeesPipe() {
    }
    /**
     * @param {?} employees
     * @param {?=} sortBy
     * @param {?=} dataType
     * @param {?=} reverse
     * @return {?}
     */
    SortEmployeesPipe.prototype.transform = /**
     * @param {?} employees
     * @param {?=} sortBy
     * @param {?=} dataType
     * @param {?=} reverse
     * @return {?}
     */
    function (employees, sortBy, dataType, reverse) {
        return this.getSorted(employees, sortBy ? sortBy : 'displayName', dataType ? dataType : 'string', reverse ? reverse : false);
    };
    /**
     * @param {?} employees
     * @param {?} sortBy
     * @param {?} dataType
     * @param {?} reverse
     * @return {?}
     */
    SortEmployeesPipe.prototype.getSorted = /**
     * @param {?} employees
     * @param {?} sortBy
     * @param {?} dataType
     * @param {?} reverse
     * @return {?}
     */
    function (employees, sortBy, dataType, reverse) {
        var /** @type {?} */ sorted = employees
            .sort(function (a, b) {
            var /** @type {?} */ valA, /** @type {?} */ valB;
            switch (dataType.toLowerCase()) {
                case 'string':
                    valA = a[sortBy] ? a[sortBy].toString().toLowerCase() : null;
                    valB = b[sortBy] ? b[sortBy].toString().toLowerCase() : null;
                    break;
                case 'number':
                    valA = a[sortBy] ? +a[sortBy] : null;
                    valB = b[sortBy] ? +b[sortBy] : null;
                    break;
                case 'date':
                    valA = a[sortBy] ? /** @type {?} */ (a[sortBy]) : null;
                    valB = b[sortBy] ? /** @type {?} */ (b[sortBy]) : null;
                    break;
            }
            if (valA < valB) {
                return -1;
            }
            if (valA > valB) {
                return 1;
            }
            return 0;
        });
        return reverse ? sorted.reverse() : sorted;
    };
    SortEmployeesPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'sortEmployees'
                },] },
    ];
    /** @nocollapse */
    SortEmployeesPipe.ctorParameters = function () { return []; };
    return SortEmployeesPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
// Services
// Pipes
var EmployeeModule = (function () {
    function EmployeeModule(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} employeeConfig
     * @return {?}
     */
    EmployeeModule.forRoot = /**
     * @param {?} employeeConfig
     * @return {?}
     */
    function (employeeConfig) {
        return {
            ngModule: EmployeeModule,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    };
    EmployeeModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [
                        DepartmentsPipe,
                        EmployeeByDnPipe,
                        EmployeesWithPropertyValuePipe,
                        FilterEmployeesPipe,
                        IsMemberOfPipe,
                        EmployeePhotoUrlPipe,
                        SortEmployeesPipe
                    ],
                    exports: [
                        DepartmentsPipe,
                        EmployeeByDnPipe,
                        EmployeesWithPropertyValuePipe,
                        FilterEmployeesPipe,
                        IsMemberOfPipe,
                        EmployeePhotoUrlPipe,
                        SortEmployeesPipe
                    ]
                },] },
    ];
    /** @nocollapse */
    EmployeeModule.ctorParameters = function () { return [
        { type: EmployeeModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return EmployeeModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SharePointPhotoUrlPipe = (function () {
    function SharePointPhotoUrlPipe() {
    }
    /**
     * @param {?} photo
     * @return {?}
     */
    SharePointPhotoUrlPipe.prototype.transform = /**
     * @param {?} photo
     * @return {?}
     */
    function (photo) {
        return photo.ows_EncodedAbsUrl;
    };
    SharePointPhotoUrlPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'sharePointPhotoUrl'
                },] },
    ];
    /** @nocollapse */
    SharePointPhotoUrlPipe.ctorParameters = function () { return []; };
    return SharePointPhotoUrlPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SharePointUrlPipe = (function () {
    function SharePointUrlPipe() {
    }
    /**
     * @param {?} url
     * @return {?}
     */
    SharePointUrlPipe.prototype.transform = /**
     * @param {?} url
     * @return {?}
     */
    function (url) {
        return url !== null ? url.split(',')[0] : null;
    };
    SharePointUrlPipe.decorators = [
        { type: Pipe, args: [{
                    name: 'sharePointUrl'
                },] },
    ];
    /** @nocollapse */
    SharePointUrlPipe.ctorParameters = function () { return []; };
    return SharePointUrlPipe;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//#region Imports
// Services
// Pipes
var SharePointModule = (function () {
    function SharePointModule(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} sharePointConfig
     * @return {?}
     */
    SharePointModule.forRoot = /**
     * @param {?} sharePointConfig
     * @return {?}
     */
    function (sharePointConfig) {
        return {
            ngModule: SharePointModule,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    };
    SharePointModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        SharePointPhotoUrlPipe,
                        SharePointUrlPipe
                    ],
                    exports: [
                        SharePointPhotoUrlPipe,
                        SharePointUrlPipe
                    ]
                },] },
    ];
    /** @nocollapse */
    SharePointModule.ctorParameters = function () { return [
        { type: SharePointModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    ]; };
    return SharePointModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

export { AuthenticationModule, AuthenticationServiceConfig, AuthenticationService, LoginComponent, LoginFormComponent, DialogModule, ConfirmationDialogMode, ConfirmationDialogComponent, InputDialogComponent, MessageDialogComponent, EmailModule, EmailServiceConfig, EmailService, EmployeeModule, EmployeeServiceConfig, EmployeeService, DepartmentsPipe, EmployeeByDnPipe, EmployeePhotoUrlPipe, EmployeesWithPropertyValuePipe, FilterEmployeesPipe, IsMemberOfPipe, SortEmployeesPipe, SharePointModule, SharePointServiceConfig, SharePointService, SharePointPhotoUrlPipe, SharePointUrlPipe };
